@@ -8,10 +8,13 @@ test_that("", {
   eps_no_loc <- eps[eps != "locations"]
 
   z <- lapply(eps_no_loc, function(x) {
-    pv_out <- search_pv("{\"patent_number\":\"5116621\"}", endpoint = x,
-                        fields = get_fields(x))
+    pv_out <- search_pv(
+      "{\"patent_number\":\"5116621\"}",
+      endpoint = x,
+      fields = get_fields(x)
+    )
     unnest_pv_data(pv_out[["data"]])
   })
 
   expect_true(TRUE)
-})
\ No newline at end of file
+})
